@@ -35,14 +35,17 @@
 #' @export
 import_data <- function(package, dataname, lib.loc = .libPaths()) {
 
+  # check library:
   .internal_check_lib.loc(lib.loc, sys.call())
 
   if(length(dataname)>1 | length(package)>1) {
     stop("only a single dataset and a single package can be given")
   }
-  return(get(
+  out <- get(
     utils::data(list=dataname, package = package, lib.loc=lib.loc, envir = environment())
-  ))
+  )
+  
+  return(out)
 }
 
 
